<template>
    <div class="dialog-table-container">
        <el-table
            :element-loading-background="loadingColor"
            v-loading="loading"
            height="70vh"
            align="center"
            :data="tableData"
            class="dialog_table"
            :cell-style="{'text-align': 'center'}"
            :header-cell-style="{'text-align': 'center'}"
        >
            <el-table-column type="index" label="序号" align="center">
            </el-table-column>
            <el-table-column prop="projectName" label="项目名称">
                <template v-slot="{row}">
                    <span @click="openSubView(item)" style="cursor: pointer">{{
                        row.projectName
                    }}</span>
                </template>
            </el-table-column>
            <el-table-column prop="score" label="完成率(%)" width="180" />
            <el-table-column prop="type" label="等级">
                <template v-slot="{row}">
                    <el-tag v-if="row.trend == 1" type="success" effect="dark"
                        >优秀</el-tag
                    >
                    <el-tag v-if="row.trend == 2" type="primary" effect="dark"
                        >良好</el-tag
                    >
                    <el-tag v-if="row.trend == 3" type="warning" effect="dark"
                        >一般</el-tag
                    >
                </template>
            </el-table-column>
        </el-table>
    </div>
</template>

<script>
import apiList from '@/api/bigScreen/majorView.js'
export default {
    name: 'monthPlan',
    props: {
        tableOptions: {
            type: Object,
            default: () => {
                return {}
            },
        },
    },
    data() {
        return {
            loading: false,
            loadingColor: 'rgba(6, 46, 106, 0.4)',
            tableData: [
                {
                    id: 1,
                    projectName: '推动数字重庆建设',
                    score: 31,
                    allSn: 1,
                    trend: 1,
                },
                {
                    id: 2,
                    projectName: '全市开发区（园区）数',
                    score: 26,
                    allSn: 2,
                    trend: 1,
                },
                {
                    id: 3,
                    projectName: '探索制造业“亩均论英雄”改革',
                    score: 23,
                    allSn: 3,
                    trend: 2,
                },
                {
                    id: 4,
                    projectName: '实施国企战略性重组和专业化整合',
                    score: 22,
                    allSn: 4,
                    trend: 2,
                },
                {
                    id: 5,
                    projectName: '建立企业上市助推机制',
                    score: 21,
                    allSn: 5,
                    trend: 2,
                },
                {
                    id: 6,
                    projectName: '探索强村富民综合改革',
                    score: 15,
                    allSn: 6,
                    trend: 2,
                },
                {
                    id: 7,
                    projectName: '探索经济区与行政区适度分离改革',
                    score: 13,
                    allSn: 7,
                    trend: 3,
                },
                {
                    id: 8,
                    projectName: '推进涉企涉民服务全生命周期“一件事一次办”',
                    score: 12,
                    allSn: 8,
                    trend: 3,
                },
                {
                    id: 9,
                    projectName: '打造“信用重庆”升级版',
                    score: 11,
                    allSn: 9,
                    trend: 3,
                },
                {
                    id: 10,
                    projectName: '建设政企学研深度融合的现代职教体系',
                    score: 9,
                    allSn: 10,
                    trend: 3,
                },
                {
                    id: 11,
                    projectName: '健全平安重庆风险闭环管控机制',
                    score: 7,
                    allSn: 11,
                    trend: 3,
                },
                {
                    id: 12,
                    projectName: '推进渝警数智“情指行”一体化现代警务改革',
                    score: 5,
                    allSn: 12,
                    trend: 3,
                },
                {
                    id: 13,
                    projectName: '建立领导班子运行评估和群众口碑评价机制',
                    score: 4,
                    allSn: 13,
                    trend: 3,
                },
                {
                    id: 14,
                    projectName: '推进“党建扎桩·治理结网”基层治理现代化改革',
                    score: 3,
                    allSn: 14,
                    trend: 3,
                },
                {
                    id: 15,
                    projectName: '实施投融资多元化改革',
                    score: 2,
                    allSn: 15,
                    trend: 3,
                },
            ],
            origin: [],
        }
    },
    mounted() {
        // this.loadData()
    },
    methods: {
        openSubView() {
            this.$router.push('/MajorProjectsSubView')
        },
        // 改革品牌榜
        loadData() {
            this.loading = true
            let data = {
                pageBean: {
                    page: 1,
                    pageSize: -1,
                    showTotal: true,
                },
                sorter: [
                    {
                        direction: 'ASC',
                        property: 'targetSn',
                    },
                ],
            }
            apiList.getProjectSpeed(data, (res) => {
                if (res && res.rows) {
                    this.origin = res.rows
                    this.mathTargetIndexFinish()
                    this.tableData = this.origin
                }
                this.loading = false
            })
        },
        // 计算优良一般比例 排名的
        // 排名的20%    优
        // 排名的30% 良
        // 排名的50%   一般
        mathTargetIndexFinish() {
            let targetSn = 0
            this.origin.forEach((item) => {
                if (targetSn < item.targetSn) {
                    targetSn = item.targetSn
                }
            })
            let level1 = targetSn * 0.2
            let level2 = targetSn * 0.5

            let level1Num = 0
            let level2Num = 0
            let level3Num = 0
            this.origin.forEach((item) => {
                if (item.targetSn <= level1) {
                    item.type = 1
                } else if (item.targetSn <= level2) {
                    item.type = 2
                } else {
                    item.type = 3
                }
            })
        },
    },
}
</script>
<style lang="scss" scoped>
.column-item-rotate {
  display: inline-block;
  transform: rotateX(180deg);
}

.cqlt-icon-arrow {
  font-size: 18px;
}

.column-trend-icon-1 {
  color: #59c06c;
  text-shadow: #59c06c 1px 0 12px;
}

.column-trend-icon-2 {
  color: #fe3b30;
  text-shadow: #fe3b30 1px 0 12px;
}
</style>
<style lang="scss">
@import './table.scss';
</style>
